==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SelectedItemsChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescriptionMetadata } from "./SelectedItemsChangedEventArgsDescriptionMetadata";
import { SelectedItemsChangingEventArgsDescription } from "./SelectedItemsChangingEventArgsDescription";
/**
 * @hidden
 */
var SelectedItemsChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectedItemsChangingEventArgsDescriptionMetadata, _super);
    function SelectedItemsChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedItemsChangingEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedItemsChangingEventArgsDescriptionMetadata.a == null) {
            SelectedItemsChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedItemsChangingEventArgsDescriptionMetadata.c(SelectedItemsChangingEventArgsDescriptionMetadata.a);
        }
        if (a.g(SelectedItemsChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(SelectedItemsChangingEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangingEventArgsDescriptionMetadata.c = function (a) {
        SelectedItemsChangedEventArgsDescriptionMetadata.c(a);
        a.item("Cancel", "Boolean");
    };
    SelectedItemsChangingEventArgsDescriptionMetadata.d = function (a) {
        SelectedItemsChangingEventArgsDescriptionMetadata.b(a);
        a.u("SelectedItemsChangingEventArgs", function () { return new SelectedItemsChangingEventArgsDescription(); });
        a.t("SelectedItemsChangingEventArgs", SelectedItemsChangingEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangingEventArgsDescriptionMetadata.$t = markType(SelectedItemsChangingEventArgsDescriptionMetadata, 'SelectedItemsChangingEventArgsDescriptionMetadata');
    SelectedItemsChangingEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangingEventArgsDescriptionMetadata;
}(Base));
export { SelectedItemsChangingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SelectedItemsChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescriptionMetadata } from "./SelectedItemsChangedEventArgsDescriptionMetadata";
import { SelectedItemsChangingEventArgsDescription } from "./SelectedItemsChangingEventArgsDescription";
/**
 * @hidden
 */
var SelectedItemsChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SelectedItemsChangingEventArgsDescriptionMetadata, _super);
    function SelectedItemsChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectedItemsChangingEventArgsDescriptionMetadata.b = function (a) {
        if (SelectedItemsChangingEventArgsDescriptionMetadata.a == null) {
            SelectedItemsChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SelectedItemsChangingEventArgsDescriptionMetadata.c(SelectedItemsChangingEventArgsDescriptionMetadata.a);
        }
        if (a.j(SelectedItemsChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SelectedItemsChangingEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangingEventArgsDescriptionMetadata.c = function (a) {
        SelectedItemsChangedEventArgsDescriptionMetadata.c(a);
        a.item("Cancel", "Boolean");
    };
    SelectedItemsChangingEventArgsDescriptionMetadata.d = function (a) {
        SelectedItemsChangingEventArgsDescriptionMetadata.b(a);
        a.aa("SelectedItemsChangingEventArgs", function () { return new SelectedItemsChangingEventArgsDescription(); });
        a.z("SelectedItemsChangingEventArgs", SelectedItemsChangingEventArgsDescriptionMetadata.a);
    };
    SelectedItemsChangingEventArgsDescriptionMetadata.$t = markType(SelectedItemsChangingEventArgsDescriptionMetadata, 'SelectedItemsChangingEventArgsDescriptionMetadata');
    SelectedItemsChangingEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangingEventArgsDescriptionMetadata;
}(Base));
export { SelectedItemsChangingEventArgsDescriptionMetadata };
